@@ -1,5 +1,5 @@
 # Copyright 2004-2009 Joe Wreschnig, Michael Urman, Steven Robertson
-#           2011-2017 Nick Boultbee
+#           2011-2020 Nick Boultbee
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,6 +15,7 @@ import sys
 import unicodedata
 import threading
 import locale
+from typing import Dict, List
 from functools import reduce
 
 # Windows doesn't have fcntl, just don't lock for now
@@ -22,7 +23,7 @@ try:
     import fcntl
     fcntl
 except ImportError:
-    fcntl = None
+    fcntl = None  # type: ignore
 
 from senf import fsnative, argv
 
@@ -38,17 +39,18 @@ from .enum import enum
 from .i18n import _, C_
 
 
-# pyflakes
+# flake8
 cached_func, enum, print_w, print_exc, is_plasma, is_unity, is_enlightenment,
 is_linux, is_windows, is_wine, is_osx, get_module_dir, get_ca_file,
 NamedTemporaryFile, is_flatpak, cmp, matches_flatpak_runtime
 
 
-class InstanceTracker(object):
+class InstanceTracker:
     """A mixin for GObjects to return a list of all alive objects
     of a given type. Note that it must be used with a GObject or
     something with a connect method and destroy signal."""
-    __kinds = {}
+
+    __kinds: Dict[type, List[object]] = {}
 
     def _register_instance(self, klass=None):
         """Register this object to be returned in the active instance list."""
@@ -62,7 +64,7 @@ class InstanceTracker(object):
         return klass.__kinds.get(klass, [])
 
 
-class OptionParser(object):
+class OptionParser:
     def __init__(self, name, version, description=None, usage=None):
         self.__name = name
         self.__version = version
@@ -148,7 +150,7 @@ class OptionParser(object):
 {title} {version}
 <{email}>
 {copyright}\
-""").format(title=self.__name, version=self.__version, dates="2004-2012",
+""").format(title=self.__name, version=self.__version,
             email=SUPPORT_EMAIL, copyright=COPYRIGHT)
 
     def parse(self, args=None):
@@ -604,7 +606,7 @@ def make_case_insensitive(filename):
     return "".join(["[%s%s]" % (c.lower(), c.upper()) for c in filename])
 
 
-class DeferredSignal(object):
+class DeferredSignal:
     """A wrapper for connecting functions to signals.
 
     Some signals may fire hundreds of times, but only require processing
@@ -751,8 +753,9 @@ def connect_after_destroy(sender, *args, **kwargs):
     return _connect_destroy(sender, sender.connect_after, *args, **kwargs)
 
 
-class cached_property(object):
-    """A read-only @property that is only evaluated once."""
+class cached_property:
+    """A read-only @property that is only evaluated once.
+    TODO: work out some typing for this, see test_query.py"""
 
     def __init__(self, fget, doc=None):
         self.fget = fget
@@ -978,7 +981,7 @@ class MainRunnerTimeoutError(MainRunnerError):
     pass
 
 
-class MainRunner(object):
+class MainRunner:
     """Schedule a function call in the main loop from a
     worker thread and wait for the result.
 
@@ -1039,7 +1042,7 @@ class MainRunner(object):
 
     def call(self, func, *args, **kwargs):
         """Runs the function in the main loop and blocks until
-        it is finshed or abort() was called. In case this is called
+        it is finished or abort() was called. In case this is called
         from the main loop the function gets executed immediately.
 
         The priority kwargs defines the event source priority and will
